@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.6.1
+# Version: 0.6.2
 # File   : AdvancedContent.module.php
 # Purpose: initial module class. this is the interface to the Module API
 # License: GPL
@@ -41,7 +41,7 @@ class AdvancedContent extends CMSModule
 	
 	function GetVersion() 
 	{
-		return '0.6.1';
+		return '0.6.2';
 	}
 	
 	function GetHelp() 
@@ -110,7 +110,7 @@ class AdvancedContent extends CMSModule
 	
 	function MaximumCMSVersion() 
 	{
-		return "1.99";
+		return "1.8.2";
 	}
 	
 	function InstallPostMessage() 
@@ -340,9 +340,13 @@ class AdvancedContent extends CMSModule
 		while($dbresult && $row = $dbresult->FetchRow()) 
 		{
 			if($row['active'])
+			{
 				$contents[$row['content_id']] = 0;
+			}
 			else
+			{
 				$contents[$row['content_id']] = 1;
+			}
 		}
 		if(count($contents)) 
 		{
@@ -353,165 +357,14 @@ class AdvancedContent extends CMSModule
 					SET active = ? WHERE content_id = ?";
 				$dbresult = $db->Execute($query, array($active, $contentId));
 				if($contentId == cmsms()->variables['pageinfo']->content_id)
+				{
 					$redirect = $contentId;
+				}
 			}
 		}
 		if($redirect) 
 		{
 			$this->RedirectContent($redirect);
-			return;
-		}
-		$access = true;
-		if( $feusers =& $this->GetModuleInstance('FrontEndUsers' ) && cmsms()->GetSmarty()->get_template_vars('content_obj')->Type() == 'content2') {
-			$feuAccess = $this->CleanArray(explode(';',cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_access')));
-			if(!empty($feuAccess)) 
-			{
-				// if page has no parents but inheritance -> remove inheritance (should never happen but just in case)
-				if(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId() <= 0 && in_array("-1",$feuAccess)) 
-				{
-					foreach($feuAccess as $k=>$v) 
-					{
-						if($v=='-1') unset($feuAccess[$k]);
-					}
-				}
-				
-				// if there still is inheritance ...
-				if(in_array('-1',$feuAccess)) 
-				{
-					// ... finally inherit
-					$feuAccess = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'feu_access',$feuAccess);
-				}
-				
-				// if we have access for certain feu groups only ...
-				if( !empty($feuAccess) ) 
-				{
-					// ... deny access by default now ...
-					$access = false;
-					// ... check if user is logged in and belongs to a group ...
-					$userId = $feusers->LoggedInId();
-					if($userId && $groups = $feusers->GetMemberGroupsArray($userId)) 
-					{
-						// compare users groups with selected ones
-						foreach($groups as $oneGroup) 
-						{
-							if(in_array($oneGroup['groupid'],$feuAccess)) 
-							{
-								// if match -> grant access
-								$access = true;
-								break;
-							}
-						}
-					}
-				}
-			}
-		}
-		if(!$access) 
-		{
-			// get the page to redirect to
-			$redirectPage = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('redirect_page');
-			if($redirectPage == '-1')
-				$redirectPage = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'redirect_page');
-			
-			// do not redirect to current page -> will result in endless recursive redirection
-			if($redirectPage == $returnid || $redirectPage == $pageinfo->content_id || $redirectPage == $pageinfo->content_alias)
-				$redirectPage = '';
-			
-			// get feu action
-			$feuAction = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_action');
-			
-			if($feuAction == '-1')
-				$feuAction = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'feu_action');
-			
-			// if we still don't have a redirect page -> do feu action in current page
-			if($redirectPage == '') 
-			{
-				// if we want an action (and we have not done this before) ...
-				if($feuAction && $mainContent && !cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_action_flag')) 
-				{
-					// ... set a flag that we already have a login form now (just to prevent to display it again for other content blocks) ...
-					cmsms()->GetSmarty()->get_template_vars('content_obj')->AddExtraProperty("feu_action_flag");
-					cmsms()->GetSmarty()->get_template_vars('content_obj')->SetPropertyValue("feu_action_flag", true);
-					// ... and finally do feu action
-					return $feusers->DoAction('default', 'cntnt01', array('form'=>'login'), $returnid);
-				}
-				else 
-				{
-					// ... otherwise just return nothing
-					return;
-				}
-				
-			}
-			// else if we have a redirect page ...
-			else 
-			{
-				// get the redirect params
-				$pattern        = '/([\w]+)=(["][^"]*["]|[\'][^\']*[\']|[^\'"\s]*)/';
-				$redirectParams = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('redirect_params');
-				$evaluateSmarty = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('evaluate_smarty');
-				if($evaluateSmarty)
-					$redirectParams = $this->ProcessTemplateFromData($redirectParams);
-				
-				$matches  = array();
-				$result   = preg_match_all($pattern, $redirectParams, $matches);
-				$_params1 = array();
-				$_params2 = array();
-				for ($i = 0; $i < count($matches[1]); $i++) 
-				{
-					if(startswith($matches[2][$i],'\''))
-						$matches[2][$i] = trim($matches[2][$i],'\'');
-					else if(startswith($matches[2][$i],'"'))
-						$matches[2][$i] = trim($matches[2][$i],'"');
-					
-					$_params1[$matches[1][$i]] = $matches[2][$i];
-					$_params2[]                = $matches[1][$i] . '=' . $matches[2][$i];
-				}
-				// if we want an action ...
-				if($feuAction) 
-				{
-					// ... redirect to the specified page and do feu action
-					return $feusers->RedirectForFrontEnd('cntnt01', $redirectPage, 'default', $_params1, false);
-				}
-				else {
-					// ... otherwise just redirect
-					$manager =& cmsms()->GetHierarchyManager();
-					$node    =& $manager->sureGetNodeByAlias($redirectPage);
-					$content =& $node->GetContent();
-					if (isset($content) && $url = $content->GetURL()) 
-					{
-						$config = cmsms()->GetConfig();
-						if(!empty($_params1) && !empty($_params2)) {
-							if($config['url_rewriting'] == 'none') 
-							{
-								if($content->DefaultContent())
-									$url .= 'index.php?' . implode('&',$_params2);
-								else
-									$url .= '&' . implode('&',$_params2);
-							}
-							else if($config['url_rewriting'] == 'internal') 
-							{
-								if($content->DefaultContent())
-									$url .= 'index.php/' . implode('/',$_params1) . '/' . $content->Alias() . $config['page_extension'];
-								else 
-								{
-									$url = str_replace($config['root_url'],
-										$config['root_url'] . '/'. implode('/',$_params1),
-										$url);
-								}
-							}
-							else if($config['url_rewriting'] == 'mod_rewrite') 
-							{
-								$url = str_replace($config['root_url'],
-									$config['root_url'] . '/'. implode('/',$_params1),
-									$url);
-								if($content->DefaultContent())
-									$url .= $content->Alias() . $config['page_extension'];
-							}
-						}
-						$this->RedirectContent($redirect);
-						return;
-					}
-				}
-			}
 		}
 	}
 	
@@ -601,7 +454,7 @@ class AdvancedContent extends CMSModule
 		$this->SetParameterType('input_id',CLEAN_STRING);
 		$this->SetParameterType('input_fields',CLEAN_STRING);
 		$this->SetParameterType('submit_bulkaction',CLEAN_INT);
-		
+		$this->SetParameterType('description',CLEAN_STRING);
 		$this->SetParameterType('inputs',CLEAN_STRING);
 		$this->SetParameterType('input_delimiter',CLEAN_STRING);
 		$this->SetParameterType('value_delimiter',CLEAN_STRING);
