@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.6.1
+# Version: 0.6.2
 # File   : contenttype.Content2.php
 #          This file is a modification of the default content type "Content"
 # Purpose: the content object
@@ -206,13 +206,13 @@ class Content2 extends CMSModuleContentType
 		return $this->lang('AdvancedContent');
 	}
 	
-	function &get_content_blocks() 
+	function get_content_blocks() 
 	{
 		$this->parse_content_blocks('get_content_blocks');
 		return $this->_contentBlocks;
 	}
 	
-	private function &_get_block_info($wholetag)
+	private function _get_block_info($wholetag)
 	{
 		$pattern   = '/([\w]+)=(["][^"]*["]|[\'][^\']*[\']|[^\'"\s]*)/';
 		$blockInfo = array();
@@ -608,24 +608,34 @@ class Content2 extends CMSModuleContentType
 			$this->_blockGroups = array();
 			#$this->_multiInputs = array();
 			
-			$this->_pageTabs['main']['block_tabs'] = array();
-			$this->_pageTabs['main']['block_groups'] = array();
-			$this->_pageTabs['main']['content_blocks'] = array();
+			$this->_pageTabs = array(
+				'main' => array(
+					'tab_id'         => 'main', 
+					'tab_name'       => lang('main'), 
+					'block_tabs'     => array(),
+					'block_groups'   => array(),
+					'content_blocks' => array()));
 			$this->_tabIds[] = 'main';
 			
 			if( check_permission(get_userid(), 'Manage All Content') ) 
 			{
-				$this->_pageTabs['options']['block_tabs'] = array();
-				$this->_pageTabs['options']['block_groups'] = array();
-				$this->_pageTabs['options']['content_blocks'] = array();
+				$this->_pageTabs['options'] = array(
+					'tab_id'         => 'options', 
+					'tab_name'       => lang('options'), 
+					'block_tabs'     => array(),
+					'block_groups'   => array(),
+					'content_blocks' => array());
 				$this->_tabIds[] = 'options';
 			}
 			
 			if( check_permission(get_userid(), 'Manage AdvancedContent Options') && $AdvancedContent->GetPreference('show_advancedcontent_options',1) ) 
 			{
-				$this->_pageTabs['AdvancedContent']['block_tabs'] = array();
-				$this->_pageTabs['AdvancedContent']['block_groups'] = array();
-				$this->_pageTabs['AdvancedContent']['content_blocks'] = array();
+				$this->_pageTabs['AdvancedContent'] = array(
+					'tab_id'         => 'AdvancedContent', 
+					'tab_name'       => 'AdvancedContent', 
+					'block_tabs'     => array(),
+					'block_groups'   => array(),
+					'content_blocks' => array());
 				$this->_tabIds[] = 'AdvancedContent';
 			}
 		}
@@ -661,7 +671,7 @@ class Content2 extends CMSModuleContentType
 				{
 					$j++;
 					
-					$blockInfo =& $this->_get_block_info($wholetag);
+					$blockInfo = $this->_get_block_info($wholetag);
 					
 					// block = active?
 					if(isset($blockInfo['active']) && $this->IsFalse($blockInfo['active'])) 
@@ -746,12 +756,27 @@ class Content2 extends CMSModuleContentType
 					|| $blockInfo['id'] == $blockInfo['id'] . '_AdvancedContentTime' 
 					|| $blockInfo['id'] == $blockInfo['id'] . '_AdvancedContentDate') 
 					{
+						$_blockId = $blockInfo['id'];
 						$blockInfo['id'] = md5($blockInfo['id'] . $j);
+						if(isset($this->_pageTabs[$pageTab]['content_blocks'][$_blockId]))
+						{
+							unset($this->_pageTabs[$pageTab]['content_blocks'][$_blockId]);
+							$this->_pageTabs[$pageTab]['content_blocks'][$blockInfo['id']] = $blockInfo['id'];
+						}
+						if(isset($this->_blockTabs[$blockTab]['content_blocks'][$_blockId]))
+						{
+							unset($this->_blockTabs[$blockTab]['content_blocks'][$_blockId]);
+							$this->_blockTabs[$blockTab]['content_blocks'][$blockInfo['id']] = $blockInfo['id'];
+						}
+						if(isset($this->_blockGroups[$blockGroup]['content_blocks'][$_blockId]))
+						{
+							unset($this->_blockGroups[$blockGroup]['content_blocks'][$_blockId]);
+							$this->_blockGroups[$blockGroup]['content_blocks'][$blockInfo['id']] = $blockInfo['id'];
+						}
 						
 						$this->_contentBlocks[$blockInfo['id']] = $blockInfo;
 						$this->_contentBlocks[$blockInfo['id']]['block_type']    = '';
-						$this->_contentBlocks[$blockInfo['id']]['default_value'] = $this->lang('error_basicattrib', $name);
-						
+						$this->_contentBlocks[$blockInfo['id']]['default_value'] = $this->lang('error_basicattrib', $blockInfo['name']);
 						continue;
 					}
 					
@@ -848,7 +873,7 @@ class Content2 extends CMSModuleContentType
 		}
 		
 		$this->parse_content_blocks('TabNames');
-		
+		#print_r($this->_pageTabs);
 		foreach($this->_pageTabs as $tab) 
 		{
 			if(!in_array($tab['tab_name'], $tabs)) 
@@ -860,6 +885,7 @@ class Content2 extends CMSModuleContentType
 				$this->_tabIds[] = $tab['tab_id'];
 			}
 		}
+		#print_r($tabs);
 		return $tabs;
 	}
 	
@@ -1133,7 +1159,6 @@ class Content2 extends CMSModuleContentType
 		foreach($this->_pageTabs[$tab_id]['content_blocks'] as $blockId) 
 		{
 			$j++;
-			
 			if(!$this->CheckBlockPermission($blockId))
 				continue;
 			
@@ -1168,13 +1193,22 @@ class Content2 extends CMSModuleContentType
 			#---
 			
 			if(($adding && $value == '') 
-			|| ($value == '' && !$this->_contentBlocks[$blockId]['allow_none']) || $this->_contentBlocks[$blockId]['new_block']) 
+			|| ($value == '' && !$this->_contentBlocks[$blockId]['allow_none']) 
+			|| $this->_contentBlocks[$blockId]['new_block']
+			|| $this->_contentBlocks[$blockId]['block_type'] == '') 
 			{
 				$value = $this->_contentBlocks[$blockId]['default_value'];
 			}
 			
-			$this->_contentBlocks[$blockId]['content'] = cms_htmlentities($value, ENT_NOQUOTES, get_encoding(''));
-			$this->_contentBlocks[$blockId]['input']   = $AdvancedContent->lang('invalid_blocktype',$this->_contentBlocks[$blockId]['block_type'],$this->_contentBlocks[$blockId]['name']);
+			if($this->_contentBlocks[$blockId]['block_type'] != '')
+			{
+				$this->_contentBlocks[$blockId]['content'] = cms_htmlentities($value, ENT_NOQUOTES, get_encoding(''));
+			}
+			else 
+			{
+				$this->_contentBlocks[$blockId]['content'] = $value;
+				$this->_contentBlocks[$blockId]['input']   = $AdvancedContent->lang('invalid_blocktype',$this->_contentBlocks[$blockId]['block_type'],$this->_contentBlocks[$blockId]['name']);
+			}
 			
 			if($this->_contentBlocks[$blockId]['label'] == ucwords($this->_contentBlocks[$blockId]['name']) 
 			&& ($blockId == md5('content_en'.$j) 
@@ -1242,7 +1276,7 @@ class Content2 extends CMSModuleContentType
 		$AdvancedContent->smarty->assign_by_ref('date_blocks', $this->_dateBlocks);
 		$AdvancedContent->smarty->assign_by_ref('content_blocks', $this->_contentBlocks);
 		$config = cmsms()->GetConfig();
-		if($config['debug']) 
+		if($config['debug'] && $tab_id == 'main') 
 		{
 			debug_buffer($this->_pageTabs,'AdvancedContent _pageTabs');
 			debug_buffer($this->_blockTabs,'AdvancedContent _blockTabs');
@@ -1934,7 +1968,7 @@ class Content2 extends CMSModuleContentType
 					cmsms()->variables['content_alias']                         = $this->mAlias;
 					cmsms()->variables['page_name']                             = $this->mAlias;
 					cmsms()->variables['position']                              = $this->mHierarchy;
-					cmsms()->variables['friendly_position']                     = ContentOperations::CreateFriendlyHierarchyPosition($this->mHierarchy);
+					cmsms()->variables['friendly_position']                     = cmsms()->GetContentOperations()->CreateFriendlyHierarchyPosition($this->mHierarchy);
 				}
 			}
 			
@@ -1946,7 +1980,7 @@ class Content2 extends CMSModuleContentType
 			$AdvancedContent->smarty->assign_by_ref('page_alias', $this->mAlias);
 			$AdvancedContent->smarty->assign_by_ref('page_name', $this->mAlias);
 			$AdvancedContent->smarty->assign_by_ref('position', $this->mHierarchy);
-			$AdvancedContent->smarty->assign_by_ref('friendly_position', ContentOperations::CreateFriendlyHierarchyPosition($this->mHierarchy));
+			$AdvancedContent->smarty->assign('friendly_position', cmsms()->GetContentOperations()->CreateFriendlyHierarchyPosition($this->mHierarchy));
 			
 			$data = $AdvancedContent->ProcessTemplateFromData(preg_replace('/:::([^:]+):::/', '{$1}', $data));
 		}
