@@ -7,7 +7,7 @@ $lang['postinstall']                    = "Module AdvancedContent %s installed."
 $lang['postuninstall']                  = "Module AdvancedContent %s uninstalled.";
 $lang['confirmuninstall']               = "Do you really want uninstall the module AdvancedContent?";
 $lang['notice_duplicatecontent']        = "<em><strong>Notice:</strong> This block is used multiple times in template. You only see the first block here.</em>";
-$lang['error_basicattrib']              = "<em><strong>Notice:</strong> Cannot use basic content property name '%s' as value of param 'block'. <br />This block is disabled. Check your page template and chose a different value of param 'block'.</em>";
+$lang['error_basicattrib']              = "<em><strong>Notice:</strong> Cannot use basic content property '%s' as value of param 'block'. <br />This block is disabled. Check your page template and chose a different value of param 'block'.</em>";
 $lang['error_expiredate']               = "End date must be later than start date.";
 $lang['youareintext']                   = "Current directory";
 $lang['dimensions']                     = "Imagesize";
@@ -252,25 +252,6 @@ in backend...</p>
 		<br />
 	</li>
 	<em><strong>Note:</strong> if the params <tt>editor_users</tt> and <tt>editor_groups</tt> are empty the block may be edited by any user with sufficient permission to edit a page</em><br /><br />
-	<li>
-		<em>(optional)</em> <tt>feu_access</tt> (not ready yet)
-		<ul>
-			<li>
-				A list of feu groups separated by a comma.<br />
-				This grants access to this content block only to certain feu groups.<br />
-			</li>
-		</ul>
-		<br />
-	</li>
-	<li>
-		<em>(optional)</em> <tt>feu_action</tt> (true/false)  (not ready yet)
-		<ul>
-			<li>
-				Specify if the login form of the feu module will be shown or not.<br />
-			</li>
-		</ul>
-		<br />
-	</li>
 	<li>
 		<em>(optional)</em> <tt>allow_none</tt> (true/false)
 		<ul>
@@ -581,8 +562,17 @@ EOT;
 $lang['changelog'] = <<<EOT
 <br />
 <p><strong>Module releases</strong>...</p>
-<ul>
-	<li><p><strong>0.6.1 (Oct 2010):</strong></p>
+<ul>fixed bug item #5651 (redirect if frontend user has no acces to that page did not work properly)
+	<li><p><strong>0.6.2 (Nov 2010):</strong></p>
+		<ul>
+			<li><p>Bugfixes:</p>
+				<ul>
+					<li><p>- minor bugfix (showed tabs of previous template when template was changed)</p></li>
+				</ul>
+			</li>
+		</ul>
+	</li>
+	<li><p><strong>0.6.1 (Nov 2010):</strong></p>
 		<ul>
 			<li><p>Bugfixes:</p>
 				<ul>
