@@ -60,6 +60,38 @@ $lang['both1'] = 'gabarit OU page';
 $lang['both2'] = 'gabarit ET page';
 $lang['content'] = 'Contenu';
 $lang['content2'] = 'Contenu avanc&eacute; (Advanced Content)';
+$lang['prefs'] = 'R&eacute;glages';
+$lang['multi_input'] = 'Multi Inputs';
+$lang['multi_input_tpl'] = 'Multi Input Templates';
+$lang['add_multi_input'] = 'Add new multi input';
+$lang['add_multi_input_tpl'] = 'Add new multi input template';
+$lang['input_id'] = 'Input ID';
+$lang['input_fields'] = 'Input fields';
+$lang['tpl_name'] = 'Nom du gabarit';
+$lang['error_template'] = 'Template is a required field and may not be empty';
+$lang['error_input_fields'] = 'Input fields is a required field and may not be empty.';
+$lang['error_input_id'] = 'No input id given or input id already exists.';
+$lang['error_input_id_exists'] = 'Input ID is already in use. Choose a different one. (must be unique)';
+$lang['multi_input_added'] = 'Multi Input added.';
+$lang['multi_input_deleted'] = 'Multi Input deleted.';
+$lang['multi_input_updated'] = 'Multi Input updated.';
+$lang['multi_input_tpl_added'] = 'Multi Input template added.';
+$lang['multi_input_tpl_updated'] = 'Multi Input template updated.';
+$lang['multi_input_tpl_deleted'] = 'Multi Input template deleted.';
+$lang['delete_selected'] = 'Effacer les &eacute;l&eacute;ments s&eacute;lcetionn&eacute;s';
+$lang['confirm_delete'] = 'Voulez vous vraiment supprimer les &eacute;l&eacute;ments s&eacute;lectionn&eacute;s ?';
+$lang['confirm_delete_selected'] = 'Do you really want do delete the selected items?';
+$lang['use_contenttype'] = 'Use contenttype';
+$lang['help_tpl_vars'] = '<p><strong>Template vars:</strong></p>
+<p><pre><code>{$inputs}</code></pre> is an array that contains all defined input elements of that multi input block.<br />
+Each input element is an array that contains all its params. <br />
+See module help for more info.<br />
+Additional param is &quot;input&quot; that will print out the input element.<br />
+To access the params use the dot syntax.<br />
+Example:</p>
+<pre><code>{foreach from=$inputs item=elm}
+	{$elm.label}:&nbsp;{$elm.input}<br />
+{/foreach}</code></pre>';
 $lang['help'] = '<br />
 <h3>Que fait ce module ?</h3>
 <p>This is a modification of the default content type &quot;Content&quot; of CMSms.<br />
@@ -689,9 +721,9 @@ $lang['changelog'] = '<br />
 	</li>
 </ul>
 <br />';
-$lang['utma'] = '156861353.1949673112.1265210769.1286953600.1286956518.214';
-$lang['utmz'] = '156861353.1286956518.214.40.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,48121.0.html|utmcmd=referral';
-$lang['qca'] = 'P0-1075820551-1265210768764';
+$lang['utma'] = '156861353.1303973178.1287758187.1288335867.1288703710.3';
+$lang['utmz'] = '156861353.1288703710.3.3.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['qca'] = 'P0-1776187459-1287758187777';
+$lang['utmb'] = '156861353.1.10.1288703710';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
