@@ -20,7 +20,7 @@ $lang['error_insufficient_blockparams'] = '<em><strong>Error:</strong> Insuffici
 $lang['yes'] = 'Ja';
 $lang['no'] = 'Nee';
 $lang['frontendaccess'] = 'Frontend Toegang';
-$lang['redirectpage'] = 'Redirect Page if no access';
+$lang['redirectpage'] = 'Verwijzen naar pagina indien geen toegang';
 $lang['showloginform'] = 'Toon login formulier';
 $lang['registeredusers'] = 'Alleen geregistreerde gebruikers';
 $lang['block'] = 'Block ';
@@ -37,29 +37,61 @@ $lang['prefsupdated'] = 'Voorkeuren bijgewerkt';
 $lang['success'] = 'Ok&eacute;';
 $lang['error'] = 'Fout';
 $lang['deletepages'] = 'Verwijder alle pagina&#039;s met het type AdvancedContent';
-$lang['importpages'] = 'Stel alle pagina&#039;s in met het type AdvancedContent.';
+$lang['importpages'] = 'Stel alle pagina&#039;s in met het type %s naar het type %s.';
 $lang['pagesimported'] = 'Alle Content pagina&#039;s ingesteld als AdvancedContent.';
-$lang['confirmimport'] = 'Do you really want to change the content type of all content pages?';
+$lang['confirmimport'] = 'Weet u zeker dat u het contenttype van alle pagina&#039;s wil wijzigen?';
 $lang['toggle_message'] = 'Verberg dit bericht';
 $lang['contentsettings'] = 'Standaard AdvancedContent Instellingen';
 $lang['redirectparams'] = 'URL params to append when redirecting (param1=value1 param2=value2 ...)';
 $lang['evaluatesmarty'] = 'Use smarty to create the params';
 $lang['error_loading_module'] = '<em><strong>Error:</strong> Could not load module &#039;%s&#039;. (Defined for block &#039;%s&#039; in your page template.)</em>';
 $lang['error_contentblock_support'] = '<em><strong>Error:</strong> Module &#039;%s&#039; does not support contentblocks. (Defined for block &#039;%s&#039; in your page template.)</em>';
-$lang['success_importpages'] = 'All pages of type %s succesfully changed to %s';
-$lang['show_advancedcontent_options'] = 'Show AdvancedContent options tab';
-$lang['display_settings'] = '%s display settings';
-$lang['save_collapse_status'] = 'Save collpase status of %s';
-$lang['content_blocks'] = 'content blocks';
-$lang['block_message'] = 'content block message';
-$lang['block_groups'] = 'block groups';
-$lang['collapse_default'] = 'Collapse %s by default';
+$lang['success_importpages'] = 'Alle pagina&#039;s van het type %s zijn succesvol gewijzigd naar %s';
+$lang['show_advancedcontent_options'] = 'Geef AdvancedContent opties tabblad weer';
+$lang['display_settings'] = '%s weergave instellingen';
+$lang['save_collapse_status'] = 'Sla de inklapstatus op van %s';
+$lang['content_blocks'] = 'content blokken';
+$lang['block_message'] = 'content blok bericht';
+$lang['block_groups'] = 'blok groepen';
+$lang['collapse_default'] = 'Klap %s standaard in';
 $lang['per_page'] = 'per pagina';
 $lang['per_template'] = 'per sjabloon';
 $lang['both1'] = 'sjabloon OF pagina ';
 $lang['both2'] = 'sjabloon EN pagina';
 $lang['content'] = 'Inhoud';
 $lang['content2'] = 'Advanced Content ';
+$lang['prefs'] = 'Instellingen';
+$lang['multi_input'] = 'Multi input';
+$lang['multi_input_tpl'] = 'Multi inputtemplates';
+$lang['add_multi_input'] = 'Voeg nieuwe multi input toe';
+$lang['add_multi_input_tpl'] = 'Voeg nieuwe multi inputtemplate toe';
+$lang['input_id'] = 'Invoer ID';
+$lang['input_fields'] = 'Invoer velden';
+$lang['tpl_name'] = 'Sjabloon naam';
+$lang['error_template'] = 'De template vereist dit veld en het mag niet leeggelaten worden';
+$lang['error_input_fields'] = 'Invoervelden is een vereist veld en mag niet leeggelaten worden.';
+$lang['error_input_id'] = 'Geen invoer id gegeven of invoer id bestaat al.';
+$lang['error_input_id_exists'] = 'Invoer ID is al in gebruik. Kies een andere (moet uniek zijn).';
+$lang['multi_input_added'] = 'Multi Input toegevoegd.';
+$lang['multi_input_deleted'] = 'Multi Input verwijderd.';
+$lang['multi_input_updated'] = 'Multi Input bijgewerkt.';
+$lang['multi_input_tpl_added'] = 'Multi Input template toegevoegd.';
+$lang['multi_input_tpl_updated'] = 'Multi Input template bijgewerkt.';
+$lang['multi_input_tpl_deleted'] = 'Multi Input template verwijderd.';
+$lang['delete_selected'] = 'Verwijder geselecteerde items';
+$lang['confirm_delete'] = 'Weet u zeker dat u dit wilt verwijderen?';
+$lang['confirm_delete_selected'] = 'Weet u zeker dat u deze wilt verwijderen?';
+$lang['use_contenttype'] = 'Gebruik Content Type';
+$lang['help_tpl_vars'] = '<p><strong>Template vars:</strong></p>
+<p><pre><code>{$inputs}</code></pre> is an array that contains all defined input elements of that multi input block.<br />
+Each input element is an array that contains all its params. <br />
+See module help for more info.<br />
+Additional param is &quot;input&quot; that will print out the input element.<br />
+To access the params use the dot syntax.<br />
+Example:</p>
+<pre><code>{foreach from=$inputs item=elm}
+	{$elm.label}:&nbsp;{$elm.input}<br />
+{/foreach}</code></pre>';
 $lang['help'] = '<br />
 <h3>What does this do?</h3>
 <p>This is a modification of the default content type &quot;Content&quot; of CMSms.<br />
@@ -148,9 +180,9 @@ in backend...</p>
 <p><strong>Advanced params:</strong></p>
 <ul>
 	<li>
-		<em>(optional)</em> <tt>block_type</tt> (text,checkbox,dropdown,select_multiple,date) 
+		<em>(optional)</em> <tt>block_type</tt> (text,checkbox,dropdown,select_multiple,date,multi_input) 
 		<ul>
-			<li>Allows you to specify what content control type is used in the back end. Supports block-parameters to include additional options.</li>
+			<li>Allows you to specify what content control type is used in the back end.</li>
 		</ul>
 		<br />
 	</li>
@@ -421,6 +453,103 @@ in backend...</p>
 		<br />
 	</li>
 </ul>
+<p><strong>Params of blocktype &quot;multi_input&quot;:</strong></p>
+<ul>
+	<li>
+		<em>(optional)</em> <tt>inputs</tt> (csv of input ids you created in the backend) 
+		<br /><br />
+	</li>
+	<li>
+		<em>(optional)</em> <tt>value_delimiter</tt> (any string) 
+		<ul>
+			<li>
+				This defines a string that devides the values of the inputs of one multi_input when stored in the database.<br />
+				Default is &quot;&amp;lt;!-- multi_input_value_dellimiter --&amp;gt;&quot;
+			</li>
+		</ul>
+		<br />
+	</li>
+	<li>
+		<em>(optional)</em> <tt>input_delimiter</tt> (any string) 
+		<ul>
+			<li>
+				This defines a string that devides the multi_inputs you defined for this content block when stored in the database.<br />
+				Default is &quot;&amp;lt;!-- multi_input_dellimiter --&amp;gt;&quot;
+			</li>
+		</ul>
+		<br />
+	</li>
+	<li>
+		<p><strong>What is a multi_input for?</strong></p>
+		<p>A multi_input block is a content block that consists of different input fields. <br />
+		You can define them in the module administration using the same syntax you use in a template when defining a content block.<br />
+		Multi inputs can be used if you want to store different values in one content block and provide different input types for each values.<br />
+		This can be usefull if you want to create a dropdown to select a module to be shown in frontend and text input to define the module parameters.<br />
+		Example for a multi_input in page template:</p>
+		<pre>
+		<code>
+		{content block=&quot;module&quot; label=&quot;Page modules&quot; block_type=&quot;multi_input&quot; inputs=&quot;module,module,module,module&quot;}
+		</code>
+		</pre>
+		<p>Example for the definition of the multi_input named &quot;module&quot;:</p>
+		<pre>
+		<code>
+		{content block=&quot;module selection&quot; block_type=&quot;dropdown&quot; items=&quot;|News|Gallery|Menu&quot;}
+		{content block=&quot;module params&quot; block_type=&quot;text&quot; oneline=true}
+		</code>
+		</pre>
+		<p>What happens if you edit a page?</p>
+		<p>It will show you a fieldset with legend &quot;Page modules&quot;. <br />
+		Inside this fieldset it shows the multi_input named &quot;module&quot; four times.<br />
+		That means you see four lines with two input fields. A dropdown and a text input.</p>
+		<p>What happens if you save a page?</p>
+		<p>The module stores the values as one single content property (aka contentblock) and separates the inputs by a given delimiter.<br />
+		Let&#039;s assume you select the News module four times with different module params like category=&quot;1&quot;, category=&quot;2&quot;, category=&quot;3&quot;, category=&quot;4&quot;.<br />
+		In the database it stores this string:</p>
+		<pre>
+		<code>
+		News&amp;lt;!-- multi_input_value_delimiter --&amp;gt;category=&quot;1&quot;&amp;lt;!-- multi_input_delimiter --&amp;gt;<br />
+		News&amp;lt;!-- multi_input_value_delimiter --&amp;gt;category=&quot;2&quot;&amp;lt;!-- multi_input_delimiter --&amp;gt;<br />
+		News&amp;lt;!-- multi_input_value_delimiter --&amp;gt;category=&quot;3&quot;&amp;lt;!-- multi_input_delimiter --&amp;gt;<br />
+		News&amp;lt;!-- multi_input_value_delimiter --&amp;gt;category=&quot;4&quot;
+		</code>
+		</pre>
+		<p>In your page template you can explode the content by the delimiters and call the selected modules.</p>
+		<p>Full Example:</p>
+		<pre>
+		<code>
+		{* define the content block *}
+		{content block=&quot;my_modules&quot; block_type=&quot;multi_input&quot; inputs=&quot;Module,Module,Module,Module&quot; assign=&quot;modules&quot;}
+		
+		{* explode block content in an array to get the input groups *}
+		{assign var=modules value=&quot;&amp;lt;!-- multi_input_delimiter --&amp;gt;&quot;|explode:$modules}
+		
+		{* loop through the selected modules *}
+		{foreach from=$modules item=&quot;module&quot;}
+			{if $module != &#039;&#039;}
+			
+				{* explode the input values in modulname and module parameters *}
+				{assign var=module_items value=&quot;&amp;lt;!-- multi_input_value_delimiter --&amp;gt;&quot;|explode:$module}
+				
+				{if$module_items[0] != &#039;&#039;}
+				
+					{* call the module *}
+					{if isset($module_items[1])}
+						{eval var=$smarty.ldelim|cat:&#039;cms_module module=&quot;&#039;|cat:$module_items[0]|cat:&#039;&quot; &#039;|cat:$module_items[1]|cat:$smarty.rdelim}
+					{else}
+						{eval var=$smarty.ldelim|cat:&#039;cms_module module=&quot;&#039;|cat:$module_items[0]|cat:&#039;&quot;&#039;|cat:$smarty.rdelim}
+					{/if}
+					
+				{/if}
+				
+			{/if}
+		
+		{/foreach}
+		</code>
+		</pre>
+	</li>
+</ul>
+
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
@@ -442,12 +571,41 @@ in backend...</p>
 	Or read it online: <a href="http://www.gnu.org/licenses/licenses.html#GPL">http://www.gnu.org/licenses/licenses.html#GPL</a><br />
 	Please read the text of the license for the full disclaimer.
 </p>
-<p>Copyright &copy; 2010, Georg Busch (NaN). All Rights Are Reserved.</p>
+<p>Copyright &amp;copy; 2010, Georg Busch (NaN). All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
 <br />';
 $lang['changelog'] = '<br />
 <p><strong>Module releases</strong>...</p>
 <ul>
+	<li><p><strong>0.7 (Nov 2010):</strong></p>
+		<ul>
+			<li><p>Bugfixes:</p>
+				<ul>
+					<li><p>- compatibility bugfixes for CMSms 1.9+ (needs CMSms 1.9 minimum now)</p></li>
+				</ul>
+			</li>
+			<li><p>Features:</p>
+				<ul>
+				<li><p>- added support of {content_module} tag</p></li>
+				</ul>
+			</li>
+		</ul>
+	</li>
+	<li><p><strong>0.6.1 (Nov 2010):</strong></p>
+		<ul>
+			<li><p>Bugfixes:</p>
+				<ul>
+					<li><p>- several bugfixes</p></li>
+					<li><p>- compatibility bugfixes for CMSms 1.9</p></li>
+				</ul>
+			</li>
+			<li><p>Features:</p>
+				<ul>
+					<li><p>- added block_type multi_input</p></li>
+				</ul>
+			</li>
+		</ul>
+	</li>
 	<li><p><strong>0.6 (Oct 2010):</strong></p>
 		<ul>
 			<li><p>Bugfixes:</p>
@@ -689,9 +847,9 @@ $lang['changelog'] = '<br />
 	</li>
 </ul>
 <br />';
-$lang['utma'] = '156861353.1335698708.1284586217.1287416776.1287421518.183';
-$lang['utmz'] = '156861353.1287154535.170.27.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,1.0.html';
-$lang['qca'] = 'P0-1551306179-1284586216711';
+$lang['utma'] = '156861353.1852221271.1287479092.1289242369.1289285035.24';
+$lang['utmz'] = '156861353.1289285035.24.21.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['qca'] = 'P0-161031897-1287479092171';
+$lang['utmb'] = '156861353.2.10.1289285035';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1287421518';
 ?>
\ No newline at end of file
